/**
 * @fileoverview Primary 3D Printer Definitions
 * For secondary definitions, please visit https://github.com/Cloud-CNC/cura-wasm-definitions
 */
declare const _default: {
    fdmextruder: {
        name: string;
        version: number;
        metadata: {
            type: string;
            author: string;
            manufacturer: string;
            setting_version: number;
            visible: boolean;
            position: string;
        };
        settings: {
            machine_settings: {
                label: string;
                type: string;
                description: string;
                children: {
                    extruder_nr: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_nozzle_id: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_nozzle_size: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_nozzle_offset_x: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_nozzle_offset_y: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_extruder_start_code: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_extruder_start_pos_abs: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_extruder_start_pos_x: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_extruder_start_pos_y: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_extruder_end_code: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_extruder_end_pos_abs: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_extruder_end_pos_x: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_extruder_end_pos_y: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    extruder_prime_pos_z: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_extruder_cooling_fan_number: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                };
            };
            platform_adhesion: {
                label: string;
                type: string;
                icon: string;
                description: string;
                children: {
                    extruder_prime_pos_x: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        enabled: boolean;
                    };
                    extruder_prime_pos_y: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        enabled: boolean;
                    };
                };
            };
            material: {
                label: string;
                icon: string;
                description: string;
                type: string;
                children: {
                    material_diameter: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                };
            };
        };
    };
    fdmprinter: {
        name: string;
        version: number;
        metadata: {
            type: string;
            author: string;
            manufacturer: string;
            setting_version: number;
            file_formats: string;
            visible: boolean;
            has_materials: boolean;
            has_variants: boolean;
            has_machine_quality: boolean;
            preferred_material: string;
            preferred_quality_type: string;
            machine_extruder_trains: {
                0: string;
            };
            supports_usb_connection: boolean;
            supports_network_connection: boolean;
        };
        settings: {
            machine_settings: {
                label: string;
                type: string;
                description: string;
                icon: string;
                children: {
                    machine_name: {
                        label: string;
                        description: string;
                        default_value: string;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_show_variants: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_start_gcode: {
                        label: string;
                        description: string;
                        default_value: string;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_end_gcode: {
                        label: string;
                        description: string;
                        default_value: string;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    material_guid: {
                        label: string;
                        description: string;
                        default_value: string;
                        type: string;
                        enabled: boolean;
                    };
                    material_diameter: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_bed_temp_wait: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    material_print_temp_wait: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    material_print_temp_prepend: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    material_bed_temp_prepend: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_width: {
                        label: string;
                        description: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_depth: {
                        label: string;
                        description: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_shape: {
                        label: string;
                        description: string;
                        default_value: string;
                        type: string;
                        options: {
                            rectangular: string;
                            elliptic: string;
                        };
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_buildplate_type: {
                        label: string;
                        description: string;
                        default_value: string;
                        type: string;
                        options: {
                            glass: string;
                            aluminum: string;
                        };
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_height: {
                        label: string;
                        description: string;
                        default_value: number;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_heated_bed: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_heated_build_volume: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_always_write_active_tool: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_center_is_zero: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_extruder_count: {
                        label: string;
                        description: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    extruders_enabled_count: {
                        label: string;
                        description: string;
                        value: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_nozzle_tip_outer_diameter: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    machine_nozzle_head_distance: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_nozzle_expansion_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        maximum_value: string;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_heat_zone_length: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_nozzle_temp_enabled: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        value: string;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_nozzle_heat_up_speed: {
                        label: string;
                        description: string;
                        default_value: number;
                        unit: string;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_nozzle_cool_down_speed: {
                        label: string;
                        description: string;
                        default_value: number;
                        unit: string;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_min_cool_heat_time_window: {
                        label: string;
                        description: string;
                        default_value: number;
                        unit: string;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_gcode_flavor: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            "RepRap (Marlin/Sprinter)": string;
                            "RepRap (Volumetric)": string;
                            "RepRap (RepRap)": string;
                            UltiGCode: string;
                            Griffin: string;
                            Makerbot: string;
                            BFB: string;
                            MACH3: string;
                            Repetier: string;
                        };
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_firmware_retract: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_extruders_share_heater: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_disallowed_areas: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: never[];
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    nozzle_disallowed_areas: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: never[];
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_head_with_fans_polygon: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number[][];
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    gantry_height: {
                        label: string;
                        description: string;
                        default_value: number;
                        value: string;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_nozzle_id: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_nozzle_size: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_use_extruder_offset_to_offset_coords: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    extruder_prime_pos_z: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    extruder_prime_pos_abs: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_max_feedrate_x: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_feedrate_y: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_feedrate_z: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_feedrate_e: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_acceleration_x: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_acceleration_y: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_acceleration_z: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_acceleration_e: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_acceleration: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_jerk_xy: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_jerk_z: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_max_jerk_e: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_steps_per_mm_x: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_steps_per_mm_y: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_steps_per_mm_z: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_steps_per_mm_e: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_endstop_positive_direction_x: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_endstop_positive_direction_y: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_endstop_positive_direction_z: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    machine_minimum_feedrate: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    machine_feeder_wheel_diameter: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                };
            };
            resolution: {
                label: string;
                type: string;
                icon: string;
                description: string;
                children: {
                    layer_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    layer_height_0: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        resolve: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    line_width: {
                        label: string;
                        description: string;
                        unit: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        type: string;
                        value: string;
                        settable_per_mesh: boolean;
                        children: {
                            wall_line_width: {
                                label: string;
                                description: string;
                                unit: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                value: string;
                                default_value: number;
                                type: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                children: {
                                    wall_line_width_0: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        default_value: number;
                                        value: string;
                                        type: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                    wall_line_width_x: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        default_value: number;
                                        value: string;
                                        type: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                };
                            };
                            skin_line_width: {
                                label: string;
                                description: string;
                                unit: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                type: string;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            infill_line_width: {
                                label: string;
                                description: string;
                                unit: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                type: string;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            skirt_brim_line_width: {
                                label: string;
                                description: string;
                                unit: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                type: string;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_line_width: {
                                label: string;
                                description: string;
                                unit: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                type: string;
                                enabled: string;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_interface_line_width: {
                                label: string;
                                description: string;
                                unit: string;
                                default_value: number;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                type: string;
                                enabled: string;
                                limit_to_extruder: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                children: {
                                    support_roof_line_width: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        default_value: number;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        type: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        value: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                    support_bottom_line_width: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        default_value: number;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        type: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        value: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                };
                            };
                            prime_tower_line_width: {
                                label: string;
                                description: string;
                                type: string;
                                unit: string;
                                enabled: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    initial_layer_line_width_factor: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                };
            };
            shell: {
                label: string;
                icon: string;
                description: string;
                type: string;
                children: {
                    wall_extruder_nr: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                        enabled: string;
                        children: {
                            wall_0_extruder_nr: {
                                label: string;
                                description: string;
                                type: string;
                                value: string;
                                default_value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                settable_per_meshgroup: boolean;
                                settable_globally: boolean;
                                enabled: string;
                            };
                            wall_x_extruder_nr: {
                                label: string;
                                description: string;
                                type: string;
                                value: string;
                                default_value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                settable_per_meshgroup: boolean;
                                settable_globally: boolean;
                                enabled: string;
                            };
                        };
                    };
                    wall_thickness: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        type: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            wall_line_count: {
                                label: string;
                                description: string;
                                default_value: number;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                type: string;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    wall_0_wipe_dist: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    roofing_extruder_nr: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                        enabled: string;
                    };
                    roofing_layer_count: {
                        label: string;
                        description: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        type: string;
                        value: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        enabled: string;
                    };
                    top_bottom_extruder_nr: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                        enabled: string;
                    };
                    top_bottom_thickness: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value: string;
                        type: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            top_thickness: {
                                label: string;
                                description: string;
                                unit: string;
                                default_value: number;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value: string;
                                type: string;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                children: {
                                    top_layers: {
                                        label: string;
                                        description: string;
                                        default_value: number;
                                        minimum_value: string;
                                        maximum_value_warning: string;
                                        type: string;
                                        minimum_value_warning: string;
                                        value: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                };
                            };
                            bottom_thickness: {
                                label: string;
                                description: string;
                                unit: string;
                                default_value: number;
                                minimum_value: string;
                                minimum_value_warning: string;
                                type: string;
                                value: string;
                                maximum_value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                children: {
                                    bottom_layers: {
                                        label: string;
                                        description: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        default_value: number;
                                        type: string;
                                        value: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                    initial_bottom_layers: {
                                        label: string;
                                        description: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        default_value: number;
                                        type: string;
                                        value: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                };
                            };
                        };
                    };
                    top_bottom_pattern: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            lines: string;
                            concentric: string;
                            zigzag: string;
                        };
                        default_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    top_bottom_pattern_0: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            lines: string;
                            concentric: string;
                            zigzag: string;
                        };
                        default_value: string;
                        enabled: string;
                        value: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    connect_skin_polygons: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    skin_angles: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    wall_0_inset: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    optimize_wall_printing_order: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                    };
                    outer_inset_first: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    alternate_extra_perimeter: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    travel_compensate_overlapping_walls_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            travel_compensate_overlapping_walls_0_enabled: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: boolean;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            travel_compensate_overlapping_walls_x_enabled: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: boolean;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    wall_min_flow: {
                        label: string;
                        description: string;
                        unit: string;
                        minimum_value: string;
                        maximum_value: string;
                        default_value: number;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    wall_min_flow_retract: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    fill_perimeter_gaps: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            nowhere: string;
                            everywhere: string;
                        };
                        default_value: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    filter_out_tiny_gaps: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    fill_outline_gaps: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    xy_offset: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    xy_offset_layer_0: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    hole_xy_offset: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    z_seam_type: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            back: string;
                            shortest: string;
                            random: string;
                            sharpest_corner: string;
                        };
                        default_value: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    z_seam_position: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            backleft: string;
                            back: string;
                            backright: string;
                            right: string;
                            frontright: string;
                            front: string;
                            frontleft: string;
                            left: string;
                        };
                        enabled: string;
                        default_value: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            z_seam_x: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            z_seam_y: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    z_seam_corner: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            z_seam_corner_none: string;
                            z_seam_corner_inner: string;
                            z_seam_corner_outer: string;
                            z_seam_corner_any: string;
                            z_seam_corner_weighted: string;
                        };
                        default_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    z_seam_relative: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    skin_no_small_gaps_heuristic: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    skin_outline_count: {
                        label: string;
                        description: string;
                        value: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        type: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    ironing_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    ironing_only_highest_layer: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    ironing_pattern: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            concentric: string;
                            zigzag: string;
                        };
                        default_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    ironing_line_spacing: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    ironing_flow: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    ironing_inset: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    speed_ironing: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    acceleration_ironing: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    jerk_ironing: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    skin_overlap: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            skin_overlap_mm: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                };
            };
            infill: {
                label: string;
                icon: string;
                description: string;
                type: string;
                children: {
                    infill_extruder_nr: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                        enabled: string;
                    };
                    infill_sparse_density: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            infill_line_distance: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                minimum_value_warning: string;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    infill_pattern: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            grid: string;
                            lines: string;
                            triangles: string;
                            trihexagon: string;
                            cubic: string;
                            cubicsubdiv: string;
                            tetrahedral: string;
                            quarter_cubic: string;
                            concentric: string;
                            zigzag: string;
                            cross: string;
                            cross_3d: string;
                            gyroid: string;
                        };
                        default_value: string;
                        enabled: string;
                        value: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    zig_zaggify_infill: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    connect_infill_polygons: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_angles: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_offset_x: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_offset_y: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_randomize_start_location: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        warning_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_multiplier: {
                        label: string;
                        description: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_wall_line_count: {
                        label: string;
                        description: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    sub_div_rad_add: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_overlap: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            infill_overlap_mm: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    infill_wipe_dist: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_sparse_thickness: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    gradual_infill_steps: {
                        label: string;
                        description: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    gradual_infill_step_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_before_walls: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    min_infill_area: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        default_value: number;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_support_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_support_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value: string;
                        default_value: number;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    skin_preshrink: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            top_skin_preshrink: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                maximum_value_warning: string;
                                minimum_value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            bottom_skin_preshrink: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                maximum_value_warning: string;
                                minimum_value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    expand_skins_expand_distance: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            top_skin_expand_distance: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            bottom_skin_expand_distance: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    max_skin_angle_for_expansion: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value: string;
                        default_value: number;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            min_skin_width_for_expansion: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    skin_edge_support_thickness: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        type: string;
                        value: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            skin_edge_support_layers: {
                                label: string;
                                description: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value_warning: string;
                                type: string;
                                value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                };
            };
            material: {
                label: string;
                icon: string;
                description: string;
                type: string;
                children: {
                    default_material_print_temperature: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: boolean;
                        settable_per_extruder: boolean;
                        settable_per_mesh: boolean;
                        minimum_value: string;
                    };
                    build_volume_temperature: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        resolve: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_print_temperature: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_print_temperature_layer_0: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_initial_print_temperature: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_final_print_temperature: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_extrusion_cool_down_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    default_material_bed_temperature: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        resolve: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    material_bed_temperature: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        resolve: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    material_bed_temperature_layer_0: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        resolve: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    material_adhesion_tendency: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        enabled: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_surface_energy: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        enabled: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_shrinkage_percentage: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        enabled: boolean;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        resolve: string;
                    };
                    material_crystallinity: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_anti_ooze_retracted_position: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        enabled: boolean;
                        minimum_value_warning: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_anti_ooze_retraction_speed: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        enabled: boolean;
                        minimum_value: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_break_preparation_retracted_position: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        enabled: boolean;
                        minimum_value_warning: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_break_preparation_speed: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        enabled: boolean;
                        minimum_value: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_break_preparation_temperature: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        value: string;
                        enabled: boolean;
                        minimum_value: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_break_retracted_position: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        enabled: boolean;
                        minimum_value_warning: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_break_speed: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        enabled: boolean;
                        minimum_value: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_break_temperature: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        enabled: boolean;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_flush_purge_speed: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        enabled: boolean;
                    };
                    material_flush_purge_length: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        enabled: boolean;
                    };
                    material_end_of_filament_purge_speed: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        enabled: boolean;
                    };
                    material_end_of_filament_purge_length: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        enabled: boolean;
                    };
                    material_maximum_park_duration: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        enabled: boolean;
                    };
                    material_no_load_move_factor: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        enabled: boolean;
                    };
                    material_flow: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            wall_material_flow: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                children: {
                                    wall_0_material_flow: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        value: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                    wall_x_material_flow: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        value: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                };
                            };
                            skin_material_flow: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            roofing_material_flow: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                enabled: string;
                            };
                            infill_material_flow: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            skirt_brim_material_flow: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_material_flow: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_interface_material_flow: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                children: {
                                    support_roof_material_flow: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        value: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                    support_bottom_material_flow: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        value: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                };
                            };
                            prime_tower_flow: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    material_flow_layer_0: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                    };
                    material_standby_temperature: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                };
            };
            speed: {
                label: string;
                icon: string;
                description: string;
                type: string;
                children: {
                    speed_print: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        children: {
                            speed_infill: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            speed_wall: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                settable_per_mesh: boolean;
                                children: {
                                    speed_wall_0: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        minimum_value: string;
                                        maximum_value: string;
                                        maximum_value_warning: string;
                                        default_value: number;
                                        value: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                    speed_wall_x: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        minimum_value: string;
                                        maximum_value: string;
                                        maximum_value_warning: string;
                                        default_value: number;
                                        value: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                };
                            };
                            speed_roofing: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                enabled: string;
                            };
                            speed_topbottom: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                            speed_support: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                limit_to_extruder: string;
                                settable_per_extruder: boolean;
                                children: {
                                    speed_support_infill: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        minimum_value: string;
                                        maximum_value: string;
                                        maximum_value_warning: string;
                                        value: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                    speed_support_interface: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        minimum_value: string;
                                        maximum_value: string;
                                        maximum_value_warning: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        value: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                        children: {
                                            speed_support_roof: {
                                                label: string;
                                                description: string;
                                                unit: string;
                                                type: string;
                                                default_value: number;
                                                minimum_value: string;
                                                maximum_value: string;
                                                maximum_value_warning: string;
                                                enabled: string;
                                                limit_to_extruder: string;
                                                value: string;
                                                settable_per_mesh: boolean;
                                                settable_per_extruder: boolean;
                                            };
                                            speed_support_bottom: {
                                                label: string;
                                                description: string;
                                                unit: string;
                                                type: string;
                                                default_value: number;
                                                minimum_value: string;
                                                maximum_value: string;
                                                maximum_value_warning: string;
                                                enabled: string;
                                                limit_to_extruder: string;
                                                value: string;
                                                settable_per_mesh: boolean;
                                                settable_per_extruder: boolean;
                                            };
                                        };
                                    };
                                };
                            };
                            speed_prime_tower: {
                                label: string;
                                description: string;
                                type: string;
                                unit: string;
                                enabled: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    speed_travel: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    speed_layer_0: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        children: {
                            speed_print_layer_0: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                settable_per_mesh: boolean;
                            };
                            speed_travel_layer_0: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                settable_per_extruder: boolean;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    skirt_brim_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    speed_z_hop: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    speed_slowdown_layers: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        resolve: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    speed_equalize_flow_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    speed_equalize_flow_max: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        enabled: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    acceleration_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        resolve: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    acceleration_print: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            acceleration_infill: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            acceleration_wall: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                children: {
                                    acceleration_wall_0: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        default_value: number;
                                        value: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                    acceleration_wall_x: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        default_value: number;
                                        value: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                };
                            };
                            acceleration_roofing: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            acceleration_topbottom: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            acceleration_support: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                limit_to_extruder: string;
                                settable_per_extruder: boolean;
                                children: {
                                    acceleration_support_infill: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        value: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                    acceleration_support_interface: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        value: string;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        maximum_value_warning: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                        children: {
                                            acceleration_support_roof: {
                                                label: string;
                                                description: string;
                                                unit: string;
                                                type: string;
                                                default_value: number;
                                                value: string;
                                                minimum_value: string;
                                                minimum_value_warning: string;
                                                maximum_value_warning: string;
                                                enabled: string;
                                                limit_to_extruder: string;
                                                settable_per_mesh: boolean;
                                                settable_per_extruder: boolean;
                                            };
                                            acceleration_support_bottom: {
                                                label: string;
                                                description: string;
                                                unit: string;
                                                type: string;
                                                default_value: number;
                                                value: string;
                                                minimum_value: string;
                                                minimum_value_warning: string;
                                                maximum_value_warning: string;
                                                enabled: string;
                                                limit_to_extruder: string;
                                                settable_per_mesh: boolean;
                                                settable_per_extruder: boolean;
                                            };
                                        };
                                    };
                                };
                            };
                            acceleration_prime_tower: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    acceleration_travel: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    acceleration_layer_0: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            acceleration_print_layer_0: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                            acceleration_travel_layer_0: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_extruder: boolean;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    acceleration_skirt_brim: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        limit_to_extruder: string;
                    };
                    jerk_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        resolve: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    jerk_print: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            jerk_infill: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            jerk_wall: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                children: {
                                    jerk_wall_0: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        minimum_value: string;
                                        maximum_value_warning: string;
                                        default_value: number;
                                        value: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                    jerk_wall_x: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        minimum_value: string;
                                        maximum_value_warning: string;
                                        default_value: number;
                                        value: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                    };
                                };
                            };
                            jerk_roofing: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            jerk_topbottom: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            jerk_support: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                limit_to_extruder: string;
                                children: {
                                    jerk_support_infill: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        value: string;
                                        minimum_value: string;
                                        maximum_value_warning: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                    jerk_support_interface: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        value: string;
                                        minimum_value: string;
                                        maximum_value_warning: string;
                                        enabled: string;
                                        limit_to_extruder: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                        children: {
                                            jerk_support_roof: {
                                                label: string;
                                                description: string;
                                                unit: string;
                                                type: string;
                                                default_value: number;
                                                value: string;
                                                minimum_value: string;
                                                maximum_value_warning: string;
                                                enabled: string;
                                                limit_to_extruder: string;
                                                settable_per_mesh: boolean;
                                                settable_per_extruder: boolean;
                                            };
                                            jerk_support_bottom: {
                                                label: string;
                                                description: string;
                                                unit: string;
                                                type: string;
                                                default_value: number;
                                                value: string;
                                                minimum_value: string;
                                                maximum_value_warning: string;
                                                enabled: string;
                                                limit_to_extruder: string;
                                                settable_per_mesh: boolean;
                                                settable_per_extruder: boolean;
                                            };
                                        };
                                    };
                                };
                            };
                            jerk_prime_tower: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    jerk_travel: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    jerk_layer_0: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            jerk_print_layer_0: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                            jerk_travel_layer_0: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_extruder: boolean;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    jerk_skirt_brim: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        limit_to_extruder: string;
                    };
                };
            };
            travel: {
                label: string;
                icon: string;
                description: string;
                type: string;
                children: {
                    retraction_enable: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retract_at_layer_change: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_amount: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            retraction_retract_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            retraction_prime_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    retraction_extra_prime_amount: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_min_travel: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_count_max: {
                        label: string;
                        description: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_extrusion_window: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    limit_support_retractions: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_combing: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            off: string;
                            all: string;
                            noskin: string;
                            infill: string;
                        };
                        default_value: string;
                        resolve: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_combing_max_distance: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    travel_retract_before_outer_wall: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    travel_avoid_other_parts: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    travel_avoid_supports: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    travel_avoid_distance: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    layer_start_x: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    layer_start_y: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    retraction_hop_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_hop_only_when_collides: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_hop: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_hop_after_extruder_switch: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    retraction_hop_after_extruder_switch_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                };
            };
            cooling: {
                label: string;
                icon: string;
                description: string;
                type: string;
                children: {
                    cool_fan_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    cool_fan_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            cool_fan_speed_min: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                value: string;
                                default_value: number;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            cool_fan_speed_max: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                default_value: number;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    cool_min_layer_time_fan_speed_max: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    cool_fan_speed_0: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        default_value: number;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    cool_fan_full_at_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            cool_fan_full_layer: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value_warning: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    cool_min_layer_time: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    cool_min_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    cool_lift_head: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                };
            };
            support: {
                label: string;
                type: string;
                icon: string;
                description: string;
                children: {
                    support_enable: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_extruder_nr: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            support_infill_extruder_nr: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: string;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_extruder_nr_layer_0: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: string;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_interface_extruder_nr: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: string;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                children: {
                                    support_roof_extruder_nr: {
                                        label: string;
                                        description: string;
                                        type: string;
                                        default_value: string;
                                        value: string;
                                        enabled: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                    support_bottom_extruder_nr: {
                                        label: string;
                                        description: string;
                                        type: string;
                                        default_value: string;
                                        value: string;
                                        enabled: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                };
                            };
                        };
                    };
                    support_structure: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            normal: string;
                            tree: string;
                        };
                        enabled: string;
                        default_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_tree_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_tree_branch_distance: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        default_value: number;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_tree_branch_diameter: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        default_value: number;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_tree_branch_diameter_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_tree_collision_resolution: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_type: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            buildplate: string;
                            everywhere: string;
                        };
                        default_value: string;
                        resolve: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_pattern: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            lines: string;
                            grid: string;
                            triangles: string;
                            concentric: string;
                            zigzag: string;
                            cross: string;
                            gyroid: string;
                        };
                        default_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_wall_count: {
                        label: string;
                        description: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        type: string;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    zig_zaggify_support: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_connect_zigzags: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_infill_rate: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            support_line_distance: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                default_value: number;
                                enabled: string;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_initial_layer_line_distance: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                default_value: number;
                                enabled: string;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    support_infill_angles: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_brim_enable: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_brim_width: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                        children: {
                            support_brim_line_count: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value_warning: string;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                limit_to_extruder: string;
                            };
                        };
                    };
                    support_z_distance: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            support_top_distance: {
                                label: string;
                                description: string;
                                unit: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                type: string;
                                enabled: string;
                                value: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                            support_bottom_distance: {
                                label: string;
                                description: string;
                                unit: string;
                                minimum_value: string;
                                maximum_value_warning: string;
                                default_value: number;
                                value: string;
                                limit_to_extruder: string;
                                type: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    support_xy_distance: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_xy_overrides_z: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            xy_overrides_z: string;
                            z_overrides_xy: string;
                        };
                        default_value: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_xy_distance_overhang: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_bottom_stair_step_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        limit_to_extruder: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_bottom_stair_step_width: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        limit_to_extruder: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_bottom_stair_step_min_slope: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        limit_to_extruder: string;
                        minimum_value: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_join_distance: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        limit_to_extruder: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_offset: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        limit_to_extruder: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_infill_sparse_thickness: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    gradual_support_infill_steps: {
                        label: string;
                        description: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    gradual_support_infill_step_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    minimum_support_area: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    support_interface_enable: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            support_roof_enable: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: boolean;
                                value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                            support_bottom_enable: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: boolean;
                                value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    support_interface_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            support_roof_height: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                            support_bottom_height: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    support_interface_skip_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_interface_density: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            support_roof_density: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                children: {
                                    support_roof_line_distance: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        value: string;
                                        limit_to_extruder: string;
                                        enabled: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                };
                            };
                            support_bottom_density: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                children: {
                                    support_bottom_line_distance: {
                                        label: string;
                                        description: string;
                                        unit: string;
                                        type: string;
                                        default_value: number;
                                        minimum_value: string;
                                        minimum_value_warning: string;
                                        value: string;
                                        limit_to_extruder: string;
                                        enabled: string;
                                        settable_per_mesh: boolean;
                                        settable_per_extruder: boolean;
                                    };
                                };
                            };
                        };
                    };
                    support_interface_pattern: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            lines: string;
                            grid: string;
                            triangles: string;
                            concentric: string;
                            zigzag: string;
                        };
                        default_value: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            support_roof_pattern: {
                                label: string;
                                description: string;
                                type: string;
                                options: {
                                    lines: string;
                                    grid: string;
                                    triangles: string;
                                    concentric: string;
                                    zigzag: string;
                                };
                                default_value: string;
                                value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_bottom_pattern: {
                                label: string;
                                description: string;
                                type: string;
                                options: {
                                    lines: string;
                                    grid: string;
                                    triangles: string;
                                    concentric: string;
                                    zigzag: string;
                                };
                                default_value: string;
                                value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    minimum_interface_area: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        children: {
                            minimum_roof_area: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                            minimum_bottom_area: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    support_interface_offset: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        maximum_value: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            support_roof_offset: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                maximum_value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_bottom_offset: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                maximum_value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    support_interface_angles: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            support_roof_angles: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: string;
                                value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            support_bottom_angles: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: string;
                                value: string;
                                limit_to_extruder: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    support_fan_enable: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_supported_skin_fan_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        minimum_value: string;
                        maximum_value: string;
                        default_value: number;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_use_towers: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_tower_diameter: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        limit_to_extruder: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_tower_maximum_supported_diameter: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        limit_to_extruder: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_tower_roof_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        default_value: number;
                        limit_to_extruder: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    support_mesh_drop_down: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    support_meshes_present: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                };
            };
            platform_adhesion: {
                label: string;
                type: string;
                icon: string;
                description: string;
                children: {
                    prime_blob_enable: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        enabled: boolean;
                        warning_value: string;
                    };
                    extruder_prime_pos_x: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        enabled: boolean;
                    };
                    extruder_prime_pos_y: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        enabled: boolean;
                    };
                    adhesion_type: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            skirt: string;
                            brim: string;
                            raft: string;
                            none: string;
                        };
                        default_value: string;
                        resolve: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    adhesion_extruder_nr: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    skirt_line_count: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    skirt_gap: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    skirt_brim_minimal_length: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    brim_width: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                        children: {
                            brim_line_count: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value_warning: string;
                                maximum_value: string;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                limit_to_extruder: string;
                            };
                        };
                    };
                    brim_gap: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    brim_replaces_support: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    brim_outside_only: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_margin: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    raft_smoothing: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    raft_airgap: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    layer_0_z_overlap: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_surface_layers: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_surface_thickness: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_surface_line_width: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_surface_line_spacing: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_interface_thickness: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_interface_line_width: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_interface_line_spacing: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_base_thickness: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_base_line_width: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_base_line_spacing: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                    };
                    raft_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        limit_to_extruder: string;
                        children: {
                            raft_surface_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                limit_to_extruder: string;
                            };
                            raft_interface_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                limit_to_extruder: string;
                            };
                            raft_base_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                limit_to_extruder: string;
                            };
                        };
                    };
                    raft_acceleration: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        limit_to_extruder: string;
                        children: {
                            raft_surface_acceleration: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                limit_to_extruder: string;
                            };
                            raft_interface_acceleration: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                limit_to_extruder: string;
                            };
                            raft_base_acceleration: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                limit_to_extruder: string;
                            };
                        };
                    };
                    raft_jerk: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        limit_to_extruder: string;
                        children: {
                            raft_surface_jerk: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                limit_to_extruder: string;
                            };
                            raft_interface_jerk: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                limit_to_extruder: string;
                            };
                            raft_base_jerk: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                limit_to_extruder: string;
                            };
                        };
                    };
                    raft_fan_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        children: {
                            raft_surface_fan_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                limit_to_extruder: string;
                            };
                            raft_interface_fan_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                limit_to_extruder: string;
                            };
                            raft_base_fan_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                maximum_value: string;
                                default_value: number;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                limit_to_extruder: string;
                            };
                        };
                    };
                };
            };
            dual: {
                label: string;
                type: string;
                icon: string;
                description: string;
                children: {
                    prime_tower_enable: {
                        label: string;
                        description: string;
                        type: string;
                        enabled: string;
                        default_value: boolean;
                        resolve: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    prime_tower_size: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        enabled: string;
                        default_value: number;
                        resolve: string;
                        minimum_value: string;
                        maximum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    prime_tower_min_volume: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    prime_tower_position_x: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        enabled: string;
                        default_value: number;
                        value: string;
                        maximum_value: string;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    prime_tower_position_y: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        enabled: string;
                        default_value: number;
                        value: string;
                        maximum_value: string;
                        minimum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    prime_tower_wipe_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        enabled: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    prime_tower_brim_enable: {
                        label: string;
                        description: string;
                        type: string;
                        enabled: string;
                        resolve: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    ooze_shield_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        resolve: string;
                        enabled: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    ooze_shield_angle: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        enabled: string;
                        default_value: number;
                        resolve: string;
                        minimum_value: string;
                        maximum_value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    ooze_shield_dist: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        enabled: string;
                        default_value: number;
                        resolve: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    switch_extruder_retraction_amount: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        enabled: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    switch_extruder_retraction_speeds: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        enabled: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            switch_extruder_retraction_speed: {
                                label: string;
                                description: string;
                                type: string;
                                unit: string;
                                enabled: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            switch_extruder_prime_speed: {
                                label: string;
                                description: string;
                                type: string;
                                unit: string;
                                enabled: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    switch_extruder_extra_prime_amount: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                };
            };
            meshfix: {
                label: string;
                type: string;
                icon: string;
                description: string;
                children: {
                    meshfix_union_all: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        settable_per_mesh: boolean;
                    };
                    meshfix_union_all_remove_holes: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                    };
                    meshfix_extensive_stitching: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                    };
                    meshfix_keep_open_polygons: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                    };
                    multiple_mesh_overlap: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    carve_multiple_volumes: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    alternate_carve_order: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    remove_empty_first_layers: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    meshfix_maximum_resolution: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                    };
                    meshfix_maximum_travel_resolution: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    meshfix_maximum_deviation: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                    };
                };
            };
            blackmagic: {
                label: string;
                type: string;
                icon: string;
                description: string;
                children: {
                    print_sequence: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            all_at_once: string;
                            one_at_a_time: string;
                        };
                        default_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    infill_mesh: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    infill_mesh_order: {
                        label: string;
                        description: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    cutting_mesh: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    mold_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                    };
                    mold_width: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        enabled: string;
                    };
                    mold_roof_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        enabled: string;
                    };
                    mold_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        enabled: string;
                    };
                    support_mesh: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    anti_overhang_mesh: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        settable_globally: boolean;
                    };
                    magic_mesh_surface_mode: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            normal: string;
                            surface: string;
                            both: string;
                        };
                        default_value: string;
                        settable_per_mesh: boolean;
                    };
                    magic_spiralize: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    smooth_spiralized_contours: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    relative_extrusion: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                };
            };
            experimental: {
                label: string;
                type: string;
                icon: string;
                description: string;
                children: {
                    slicing_tolerance: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            middle: string;
                            exclusive: string;
                            inclusive: string;
                        };
                        default_value: string;
                        settable_per_mesh: boolean;
                    };
                    roofing_line_width: {
                        label: string;
                        description: string;
                        unit: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        default_value: number;
                        type: string;
                        value: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        enabled: string;
                    };
                    roofing_pattern: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            lines: string;
                            concentric: string;
                            zigzag: string;
                        };
                        default_value: string;
                        value: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        enabled: string;
                    };
                    roofing_angles: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    infill_enable_travel_optimization: {
                        label: string;
                        description: string;
                        type: string;
                        enabled: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                    };
                    material_flow_dependent_temperature: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    material_flow_temp_graph: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    minimum_polygon_circumference: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_skip_some_zags: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_skip_zag_per_mm: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            support_zag_skip_count: {
                                label: string;
                                description: string;
                                type: string;
                                default_value: number;
                                value: string;
                                minimum_value: string;
                                minimum_value_warning: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    draft_shield_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    draft_shield_dist: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        resolve: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    draft_shield_height_limitation: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            full: string;
                            limited: string;
                        };
                        default_value: string;
                        resolve: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    draft_shield_height: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    conical_overhang_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                    };
                    conical_overhang_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value: string;
                        default_value: number;
                        enabled: string;
                    };
                    coasting_enable: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    coasting_volume: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    coasting_min_volume: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    coasting_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    cross_infill_pocket_size: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    cross_infill_density_image: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    cross_support_density_image: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    support_conical_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    support_conical_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        default_value: number;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    support_conical_min_width: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        type: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    magic_fuzzy_skin_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    magic_fuzzy_skin_outside_only: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    magic_fuzzy_skin_thickness: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                    };
                    magic_fuzzy_skin_point_density: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        maximum_value: string;
                        enabled: string;
                        limit_to_extruder: string;
                        settable_per_mesh: boolean;
                        children: {
                            magic_fuzzy_skin_point_dist: {
                                label: string;
                                description: string;
                                type: string;
                                unit: string;
                                default_value: number;
                                minimum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                value: string;
                                enabled: string;
                                limit_to_extruder: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    flow_rate_max_extrusion_offset: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    flow_rate_extrusion_offset_factor: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_height: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_roof_inset: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        value: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_printspeed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        children: {
                            wireframe_printspeed_bottom: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                settable_per_meshgroup: boolean;
                            };
                            wireframe_printspeed_up: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                settable_per_meshgroup: boolean;
                            };
                            wireframe_printspeed_down: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                settable_per_meshgroup: boolean;
                            };
                            wireframe_printspeed_flat: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                maximum_value_warning: string;
                                value: string;
                                enabled: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                settable_per_meshgroup: boolean;
                            };
                        };
                    };
                    wireframe_flow: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                        children: {
                            wireframe_flow_connection: {
                                label: string;
                                description: string;
                                unit: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value_warning: string;
                                type: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                settable_per_meshgroup: boolean;
                            };
                            wireframe_flow_flat: {
                                label: string;
                                description: string;
                                unit: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value_warning: string;
                                type: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                                settable_per_meshgroup: boolean;
                            };
                        };
                    };
                    wireframe_top_delay: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_bottom_delay: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_flat_delay: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_up_half_speed: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_top_jump: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_fall_down: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_drag_along: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_strategy: {
                        label: string;
                        description: string;
                        type: string;
                        options: {
                            compensate: string;
                            knot: string;
                            retract: string;
                        };
                        default_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_straight_before_down: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_roof_fall_down: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_roof_drag_along: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_roof_outer_delay: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wireframe_nozzle_clearance: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    adaptive_layer_height_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    adaptive_layer_height_variation: {
                        label: string;
                        description: string;
                        type: string;
                        enabled: string;
                        unit: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    adaptive_layer_height_variation_step: {
                        label: string;
                        description: string;
                        type: string;
                        enabled: string;
                        default_value: number;
                        unit: string;
                        settable_per_mesh: boolean;
                        minimum_value: string;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    adaptive_layer_height_threshold: {
                        label: string;
                        description: string;
                        type: string;
                        enabled: string;
                        default_value: number;
                        unit: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wall_overhang_angle: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                    };
                    wall_overhang_speed_factor: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_settings_enabled: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        resolve: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    bridge_wall_min_length: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        default_value: number;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    bridge_skin_support_threshold: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_sparse_infill_max_density: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_wall_coast: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_wall_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_wall_material_flow: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_skin_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_skin_material_flow: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_skin_density: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        minimum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_fan_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        minimum_value: string;
                        maximum_value: string;
                        default_value: number;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_enable_more_layers: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_skin_speed_2: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_skin_material_flow_2: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_skin_density_2: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        minimum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_fan_speed_2: {
                        label: string;
                        description: string;
                        unit: string;
                        minimum_value: string;
                        maximum_value: string;
                        default_value: number;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_skin_speed_3: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_skin_material_flow_3: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_skin_density_3: {
                        label: string;
                        description: string;
                        unit: string;
                        default_value: number;
                        type: string;
                        minimum_value: string;
                        maximum_value: string;
                        minimum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    bridge_fan_speed_3: {
                        label: string;
                        description: string;
                        unit: string;
                        minimum_value: string;
                        maximum_value: string;
                        default_value: number;
                        type: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                    };
                    clean_between_layers: {
                        label: string;
                        description: string;
                        default_value: boolean;
                        type: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    max_extrusion_before_wipe: {
                        label: string;
                        description: string;
                        default_value: number;
                        type: string;
                        unit: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wipe_retraction_enable: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wipe_retraction_amount: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wipe_retraction_extra_prime_amount: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                    };
                    wipe_retraction_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value: string;
                        maximum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        children: {
                            wipe_retraction_retract_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                            wipe_retraction_prime_speed: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                default_value: number;
                                minimum_value: string;
                                maximum_value: string;
                                minimum_value_warning: string;
                                maximum_value_warning: string;
                                enabled: string;
                                value: string;
                                settable_per_mesh: boolean;
                                settable_per_extruder: boolean;
                            };
                        };
                    };
                    wipe_pause: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wipe_hop_enable: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: boolean;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wipe_hop_amount: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wipe_hop_speed: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wipe_brush_pos_x: {
                        label: string;
                        description: string;
                        type: string;
                        unit: string;
                        default_value: number;
                        minimum_value_warning: string;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wipe_repeat_count: {
                        label: string;
                        description: string;
                        type: string;
                        minimum_value: string;
                        default_value: number;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    wipe_move_distance: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        enabled: string;
                        settable_per_mesh: boolean;
                        settable_per_extruder: boolean;
                        settable_per_meshgroup: boolean;
                    };
                    small_hole_max_size: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        minimum_value: string;
                        default_value: number;
                        settable_per_mesh: boolean;
                        children: {
                            small_feature_max_length: {
                                label: string;
                                description: string;
                                unit: string;
                                type: string;
                                minimum_value: string;
                                default_value: number;
                                value: string;
                                settable_per_mesh: boolean;
                            };
                        };
                    };
                    small_feature_speed_factor: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                    };
                    small_feature_speed_factor_0: {
                        label: string;
                        description: string;
                        unit: string;
                        type: string;
                        default_value: number;
                        value: string;
                        minimum_value: string;
                        minimum_value_warning: string;
                        maximum_value_warning: string;
                        settable_per_mesh: boolean;
                    };
                };
            };
            command_line_settings: {
                label: string;
                description: string;
                type: string;
                enabled: boolean;
                children: {
                    center_object: {
                        description: string;
                        type: string;
                        label: string;
                        default_value: boolean;
                        enabled: boolean;
                    };
                    mesh_position_x: {
                        description: string;
                        type: string;
                        label: string;
                        default_value: number;
                        enabled: boolean;
                    };
                    mesh_position_y: {
                        description: string;
                        type: string;
                        label: string;
                        default_value: number;
                        enabled: boolean;
                    };
                    mesh_position_z: {
                        description: string;
                        type: string;
                        label: string;
                        default_value: number;
                        enabled: boolean;
                    };
                    mesh_rotation_matrix: {
                        label: string;
                        description: string;
                        type: string;
                        default_value: string;
                        enabled: boolean;
                    };
                };
            };
        };
    };
};
export default _default;
